oncvpsp-tools |release| Documentation
=====================================

``oncvpsp-tools`` implements the input and output files of the `ONCVPSP pseudopotential generator <http://www.mat-simresearch.com/>`_ as Python dataclasses, allowing them to be easily manipluated and plotted.

Table of Contents
-----------------
.. toctree::
   :maxdepth: 2

   installation
   usage
   cli
